@@ -1,4 +1,4 @@
-# $Id: mirror_sites.tcl 108181 2013-07-15 14:26:07Z ryandesign@macports.org $
+# $Id: mirror_sites.tcl 120015 2014-05-13 14:15:39Z devans@macports.org $
 #
 # List of master site classes for use in Portfiles
 # Most of these are taken shamelessly from FreeBSD.
@@ -26,7 +26,6 @@ set portfetch::mirror_sites::sites(apache) {
     http://mirror.internode.on.net/pub/apache/
     http://www.mirrorservice.org/sites/ftp.apache.org/
     http://mirror.aarnet.edu.au/pub/apache/
-    http://apache-mirror.dkuug.dk/
     http://apache.is.co.za/
     http://mirror.facebook.net/apache/
     http://apache.pesat.net.id/
@@ -155,56 +154,68 @@ set portfetch::mirror_sites::sites(gentoo) {
 
 set portfetch::mirror_sites::sites(gimp) {
     http://ftp.gtk.org/pub/
-    ftp://ftp.gtk.org/pub/
-    ftp://ftp.gimp.org/pub/
-    http://gimp.mirrors.hoobly.com/
-    http://gimp.cp-dev.com/
-    http://gimp.promotionalpromos.com/
-    http://gimp.sixsigmaonline.org/
-    http://www.mirrorservice.org/sites/ftp.gimp.org/pub/
-    http://piotrkosoft.net/pub/mirrors/ftp.gimp.org/pub/
-    ftp://gd.tuwien.ac.at/graphics/gimp/
-    ftp://ftp.funet.fi/pub/sci/graphics/packages/
-    http://ftp.iut-bm.univ-fcomte.fr/gimp/
-    ftp://ftp.gwdg.de/pub/misc/grafik/gimp/
+    http://download.gimp.org/pub/
+    http://artfiles.org/gimp.org/
+    ftp://ftp.cc.uoc.gr/mirrors/gimp/
     http://ftp.gwdg.de/pub/misc/grafik/gimp/
-    ftp://ftp.esat.net/mirrors/ftp.gimp.org/pub/
-    http://ftp.esat.net/mirrors/ftp.gimp.org/pub/
-    ftp://ftp.heanet.ie/mirrors/ftp.gimp.org/pub/
     http://ftp.heanet.ie/mirrors/ftp.gimp.org/pub/
-    ftp://ftp.u-aizu.ac.jp/pub/graphics/tools/gimp/
-    ftp://ftp.ring.gr.jp/pub/graphics/
-    http://www.ring.gr.jp/pub/graphics/
-    ftp://ftp.snt.utwente.nl/pub/software/gimp/
-    http://ftp.snt.utwente.nl/pub/software/gimp/
-    ftp://sunsite.icm.edu.pl/pub/graphics/
-    ftp://ftp.sai.msu.su/pub/unix/graphics/gimp/mirror/
-    http://sunsite.rediris.es/mirror/
-    ftp://ftp.rediris.es/mirror/
-    ftp://ftp.acc.umu.se/pub/gimp/
-    ftp://ftp.sunet.se/pub/gnu/
-    http://ftp.sunet.se/pub/gnu/
     ftp://ftp.is.co.za/mirror/ftp.gimp.org/
+    http://ftp.iut-bm.univ-fcomte.fr/
+    ftp://ftp.mirrorservice.org/sites/ftp.gimp.org/pub/
+    http://ftp.nluug.nl/graphics/
+    ftp://ftp.nluug.nl/pub/graphics/
+    ftp://ftp.piotrkosoft.net/pub/mirrors/ftp.gimp.org/pub/
+    ftp://ftp.rediris.es/mirror/
+    ftp://ftp.sai.msu.su/pub/unix/graphics/gimp/mirror/
+    http://ftp.snt.utwente.nl/pub/software/gimp/
+    http://ftp.sunet.se/pub/gnu/
+    ftp://ftp.tpnet.pl/pub/graphics/
+    ftp://ftp.u-aizu.ac.jp/pub/graphics/tools/gimp/
+    http://gimp.cp-dev.com/
+    http://gimp.mirrors.hoobly.com/
+    http://gimp.parentingamerica.com/
+    http://gimp.raffsoftware.com/
+    http://gimp.skazkaforyou.com/
+    http://mirror.hessmo.com/
+    http://mirror.ibcp.fr/pub/
+    http://mirror.umd.edu/gimp/
+    http://mirrors-br.go-parts.com/
+    http://mirrors.dominios.pt/
+    ftp://mirrors.fe.up.pt/mirrors/ftp.gimp.org/pub/
+    http://mirrors.fe.up.pt/mirrors/ftp.gimp.org/pub/
+    http://mirrors.go-parts.com/
+    http://mirrors.serverhost.ro/
+    http://mirrors.xmission.com/gimp/
+    http://mirrors.zerg.biz/
+    http://piotrkosoft.net/pub/mirrors/ftp.gimp.org/pub/
+    ftp://sunsite.icm.edu.pl/pub/graphics/
+    http://sunsite.rediris.es/mirror/
+    http://www.mirrorservice.org/sites/ftp.gimp.org/pub/
+    http://www.ring.gr.jp/pub/graphics/
 }
 
 set portfetch::mirror_sites::sites(gnome) {
+    http://ftp.gnome.org/pub/GNOME/
+    http://artfiles.org/gnome.org/
+    http://fr2.rpmfind.net/linux/gnome.org/
+    http://ftp.acc.umu.se/pub/GNOME/
+    http://ftp.belnet.be/ftp.gnome.org/
     ftp://ftp.cse.buffalo.edu/pub/Gnome/
+    http://ftp.df.lth.se/pub/gnome/
+    http://ftp.is.co.za/mirror/ftp.gnome.org/
+    ftp://ftp.kddlabs.co.jp/pub/GNOME/
+    http://ftp.nara.wide.ad.jp/pub/X11/GNOME/
+    http://ftp.rpmfind.net/linux/gnome.org/
+    http://ftp.sunet.se/pub/X11/GNOME/
+    http://ftp1.nluug.nl/windowing/gnome/
+    http://ftp2.nluug.nl/windowing/gnome/
+    http://ftp2.uk.freebsd.org/sites/ftp.gnome.org/pub/GNOME/
+    http://mirror.internode.on.net/pub/gnome/
+    http://mirror.oss.maxcdn.com/gnome/
+    http://mirror.umd.edu/gnome/
+    http://mirrors.ustc.edu.cn/gnome/
     http://www.gtlib.gatech.edu/pub/gnome/
     http://www.mirrorservice.org/sites/ftp.gnome.org/pub/GNOME/
-    http://fr2.rpmfind.net/linux/gnome.org/
-    http://mirror.aarnet.edu.au/pub/gnome/
-    http://ftp.unina.it/pub/linux/GNOME/
-    http://ftp.acc.umu.se/pub/GNOME/
-    http://ftp.belnet.be/mirror/ftp.gnome.org/
-    http://ftp.nara.wide.ad.jp/pub/X11/GNOME/
-    ftp://ftp.dit.upm.es/pub/GNOME/
-    ftp://ftp.no.gnome.org/pub/GNOME/
-    ftp://ftp.nara.wide.ad.jp/pub/X11/GNOME/
-    ftp://ftp.kddlabs.co.jp/pub/GNOME/
-    http://mirror.internode.on.net/pub/gnome/
-    http://ftp.df.lth.se/pub/gnome/
-    http://linorg.usp.br/gnome/
-    http://ftp.gnome.org/pub/GNOME/
 }
 
 set portfetch::mirror_sites::sites(gnu) {
@@ -246,8 +257,6 @@ set portfetch::mirror_sites::sites(googlecode) {
 set portfetch::mirror_sites::sites(isc) {
     http://www.mirrorservice.org/sites/ftp.isc.org/isc/
     ftp://ftp.nominum.com/pub/isc/
-    http://mirrors.24-7-solutions.net/pub/isc/
-    http://www.mirrorservice.org/sites/ftp.isc.org/isc/
     ftp://gd.tuwien.ac.at/infosys/servers/isc/
     http://ftp.arcane-networks.fr/pub/mirrors/ftp.isc.org/isc/
     ftp://ftp.ciril.fr/pub/isc/
@@ -294,6 +303,7 @@ set portfetch::mirror_sites::sites(macports_distfiles) {
     http://her.gr.distfiles.macports.org/mirrors/macports/mpdistfiles/:mirror
     http://jog.id.distfiles.macports.org/macports/mpdistfiles/:mirror
     http://lil.fr.distfiles.macports.org/:mirror
+    http://nue.de.distfiles.macports.org/macports/distfiles/:mirror
     http://mse.uk.distfiles.macports.org/sites/distfiles.macports.org/:mirror
     http://sea.us.distfiles.macports.org/macports/distfiles/:mirror
     http://ykf.ca.distfiles.macports.org/MacPorts/mpdistfiles/:mirror
@@ -329,7 +339,6 @@ set portfetch::mirror_sites::sites(openbsd) {
 set portfetch::mirror_sites::sites(perl_cpan) {
     http://mirrors.ibiblio.org/CPAN/modules/by-module/
     http://www.mirrorservice.org/sites/ftp.cpan.org/pub/CPAN/modules/by-module/
-    http://ftp.ucr.ac.cr/Unix/CPAN/modules/by-module/
     ftp://ftp.funet.fi/pub/languages/perl/CPAN/modules/by-module/
     ftp://ftp.kddlabs.co.jp/lang/perl/CPAN/modules/by-module/
     ftp://ftp.sunet.se/pub/lang/perl/CPAN/modules/by-module/
@@ -348,34 +357,58 @@ set portfetch::mirror_sites::sites(perl_cpan) {
 # http://php.net/mirrors.php
 # The country code domains without number suffix are supposed to redirect to
 # an available mirror in that country. To update this list use:
-# curl -s http://php.net/mirrors.php | sed -E -n 's,^.*http://([a-z]{2})[0-9]*(\.php\.net)/.*$,\1\2,p' | sort -u | xargs -n 1 -I % sh -c '{ ping -o -c 4 -t 15 % >/dev/null 2>&1 && echo "    http://%/:nosubdir"; }' | tee /dev/tty | pbcopy
+# curl -s --compressed http://php.net/mirrors.php | sed -E -n 's,^.*http://([a-z]{2})[0-9]*(\.php\.net)/.*$,\1\2,p' | sort -u | xargs -n 1 -I % sh -c '{ curl -s --compressed --connect-timeout 30 -m 60 http://%/ | grep -iq "php group" && echo "    http://%/:nosubdir"; }' | tee /dev/tty | pbcopy
 set portfetch::mirror_sites::sites(php) {
+    http://am.php.net/:nosubdir
+    http://ar.php.net/:nosubdir
     http://at.php.net/:nosubdir
+    http://au.php.net/:nosubdir
+    http://bd.php.net/:nosubdir
     http://be.php.net/:nosubdir
-    http://br.php.net/:nosubdir
+    http://bg.php.net/:nosubdir
     http://ca.php.net/:nosubdir
     http://ch.php.net/:nosubdir
+    http://cl.php.net/:nosubdir
+    http://cz.php.net/:nosubdir
     http://de.php.net/:nosubdir
     http://dk.php.net/:nosubdir
     http://ee.php.net/:nosubdir
+    http://es.php.net/:nosubdir
     http://fi.php.net/:nosubdir
     http://fr.php.net/:nosubdir
     http://hk.php.net/:nosubdir
+    http://hu.php.net/:nosubdir
+    http://id.php.net/:nosubdir
     http://ie.php.net/:nosubdir
+    http://il.php.net/:nosubdir
     http://in.php.net/:nosubdir
+    http://ir.php.net/:nosubdir
     http://is.php.net/:nosubdir
+    http://it.php.net/:nosubdir
+    http://jm.php.net/:nosubdir
     http://jp.php.net/:nosubdir
+    http://kr.php.net/:nosubdir
+    http://li.php.net/:nosubdir
+    http://lu.php.net/:nosubdir
+    http://lv.php.net/:nosubdir
+    http://md.php.net/:nosubdir
     http://mx.php.net/:nosubdir
+    http://my.php.net/:nosubdir
     http://nc.php.net/:nosubdir
+    http://nl.php.net/:nosubdir
     http://no.php.net/:nosubdir
     http://nz.php.net/:nosubdir
     http://pa.php.net/:nosubdir
+    http://pk.php.net/:nosubdir
     http://pl.php.net/:nosubdir
     http://pt.php.net/:nosubdir
     http://ro.php.net/:nosubdir
+    http://ru.php.net/:nosubdir
     http://se.php.net/:nosubdir
     http://sg.php.net/:nosubdir
+    http://th.php.net/:nosubdir
     http://tr.php.net/:nosubdir
+    http://tw.php.net/:nosubdir
     http://tz.php.net/:nosubdir
     http://ua.php.net/:nosubdir
     http://uk.php.net/:nosubdir
@@ -419,7 +452,6 @@ set portfetch::mirror_sites::sites(savannah) {
     http://mirrors.zerg.biz/nongnu/
     http://savannah.c3sl.ufpr.br/
     ftp://savannah.c3sl.ufpr.br/savannah-nongnu/
-    http://www.de-mirrors.de/nongnu/
 }
 # Alias nongnu to savannah
 set portfetch::mirror_sites::sites(nongnu) $portfetch::mirror_sites::sites(savannah)
@@ -431,16 +463,16 @@ set portfetch::mirror_sites::sites(sourceforge) {
     http://freefr.dl.sourceforge.net/
     http://garr.dl.sourceforge.net/
     http://heanet.dl.sourceforge.net/
-    http://ignum.dl.sourceforge.net/
+    http://hivelocity.dl.sourceforge.net/
     http://internode.dl.sourceforge.net/
-    http://iweb.dl.sourceforge.net/
     http://jaist.dl.sourceforge.net/
+    http://kent.dl.sourceforge.net/
     http://nchc.dl.sourceforge.net/
     http://netcologne.dl.sourceforge.net/
+    http://optimate.dl.sourceforge.net/
+    http://softlayer-dal.dl.sourceforge.net/
     http://superb-dca2.dl.sourceforge.net/
-    http://superb-dca3.dl.sourceforge.net/
     http://switch.dl.sourceforge.net/
-    http://tenet.dl.sourceforge.net/
     http://ufpr.dl.sourceforge.net/
     http://waix.dl.sourceforge.net/
 }
@@ -544,3 +576,65 @@ set portfetch::mirror_sites::sites(xorg) {
     http://www.x.org/pub/
     ftp://ftp.x.org/pub/
 }
+
+# MySQL Mirrors
+# To update this list use:
+# $ curl -s http://dev.mysql.com/downloads/mirrors.html | grep -E '>HTTP<' | sed -e 's,.*href="\(.*\)">.*,    \1/Downloads/:nosubdir,g' -e 's,//Downloads/:nosubdir,/Downloads/:nosubdir,g' | sort -u
+# To remove bad mirrors look at this inexpensive output:
+# $ for port in mysql{5,51,55,56} ; do echo "port: ${port}" ; for mirror in $(port distfiles $port | grep -v macports | grep -E "^ *(http|ftp)://") ; do echo $mirror ; curl -sI $mirror | grep -E "(^213|Content-Length)" | sed -e '/Content-Length/ s/.*: //' -e '/213/ s/.* //' ; done ; done
+# Mirrors with bad or missing files
+#     http://mirror-cybernet.lums.edu.pk/pub/mysql/Downloads/:nosubdir
+#     http://mysql.isu.edu.tw/Downloads/:nosubdir
+#     http://mysql.mirror.kangaroot.net/Downloads/:nosubdir
+#     http://mysql.mirrors.crysys.hit.bme.hu/Downloads/:nosubdir
+#     http://mysql.mirrors.ilisys.com.au/Downloads/:nosubdir
+#     http://mysql.mivzakim.net/Downloads/:nosubdir
+#     http://opensource.become.com/mysql/Downloads/:nosubdir
+#     http://sunsite.informatik.rwth-aachen.de/mysql/Downloads/:nosubdir
+# Mirrors with ping failures
+#     http://ftp.itu.edu.tr/Mirror/Mysql/Downloads/:nosubdir
+#     http://mysql.blic.net/Downloads/:nosubdir
+#     http://mysql.cs.pu.edu.tw/Downloads/:nosubdir
+#     http://mysql.dataphone.se/Downloads/:nosubdir
+set portfetch::mirror_sites::sites(mysql) {
+    http://artfiles.org/mysql/Downloads/:nosubdir
+    http://ftp.arnes.si/mysql/Downloads/:nosubdir
+    http://ftp.gwdg.de/pub/misc/mysql/Downloads/:nosubdir
+    http://ftp.heanet.ie/mirrors/www.mysql.com/Downloads/:nosubdir
+    http://ftp.iij.ad.jp/pub/db/mysql/Downloads/:nosubdir
+    http://ftp.jaist.ac.jp/pub/mysql/Downloads/:nosubdir
+    http://ftp.ntua.gr/pub/databases/mysql/Downloads/:nosubdir
+    http://ftp.sunet.se/pub/unix/databases/relational/mysql/Downloads/:nosubdir
+    http://gd.tuwien.ac.at/db/mysql/Downloads/:nosubdir
+    http://it.mysql.contactlab.it/Downloads/:nosubdir
+    http://linorg.usp.br/mysql/Downloads/:nosubdir
+    http://mirror.csclub.uwaterloo.ca/mysql/Downloads/:nosubdir
+    http://mirror.leaseweb.com/mysql/Downloads/:nosubdir
+    http://mirror.switch.ch/ftp/mirror/mysql/Downloads/:nosubdir
+    http://mirror.trouble-free.net/mysql_mirror/Downloads/:nosubdir
+    http://mirrors.dedipower.com/www.mysql.com/Downloads/:nosubdir
+    http://mirrors.dotsrc.org/mysql/Downloads/:nosubdir
+    http://mirrors.ircam.fr/pub/mysql/Downloads/:nosubdir
+    http://mirrors.ukfast.co.uk/sites/ftp.mysql.com/Downloads/:nosubdir
+    http://mirrors.xservers.ro/mysql/Downloads/:nosubdir
+    http://mysql.cdpa.nsysu.edu.tw/Downloads/:nosubdir
+    http://mysql.he.net/Downloads/:nosubdir
+    http://mysql.infocom.ua/Downloads/:nosubdir
+    http://mysql.inspire.net.nz/Downloads/:nosubdir
+    http://mysql.linux.cz/Downloads/:nosubdir
+    http://mysql.llarian.net/Downloads/:nosubdir
+    http://mysql.mirror.ac.za/Downloads/:nosubdir
+    http://mysql.mirror.iweb.ca/Downloads/:nosubdir
+    http://mysql.mirror.rafal.ca/Downloads/:nosubdir
+    http://mysql.mirrors.arminco.com/Downloads/:nosubdir
+    http://mysql.mirrors.hoobly.com/Downloads/:nosubdir
+    http://mysql.mirrors.ovh.net/ftp.mysql.com/Downloads/:nosubdir
+    http://mysql.mirrors.pair.com/Downloads/:nosubdir
+    http://mysql.nfsi.pt/Downloads/:nosubdir
+    http://mysql.ntu.edu.tw/Downloads/:nosubdir
+    http://mysql.spd.co.il/Downloads/:nosubdir
+    http://na.mirror.garr.it/mirrors/MySQL/Downloads/:nosubdir
+    http://sunsite.icm.edu.pl/mysql/Downloads/:nosubdir
+    http://www.linorg.usp.br/mysql/Downloads/:nosubdir
+    http://www.mirrorservice.org/sites/ftp.mysql.com/Downloads/:nosubdir
+}
