@@ -1,7 +1,7 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:ft=tcl:et:sw=4:ts=4:sts=4
-# $Id: app-1.0.tcl 96776 2012-08-19 05:52:01Z blair@macports.org $
+# $Id: app-1.0.tcl 113311 2013-11-13 14:14:03Z ryandesign@macports.org $
 #
-# Copyright (c) 2011 The MacPorts Project
+# Copyright (c) 2011-2013 The MacPorts Project
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -157,7 +157,7 @@ if {[info commands lreverse] == ""} {
 
 
 platform macosx {
-    post-destroot {
+    pre-destroot {
         if {[tbool app.create]} {
             # Ensure app.name is valid.
             if {[regexp {[/]} ${app.name}]} {
@@ -167,7 +167,11 @@ platform macosx {
             # Make the app bundle directories.
             xinstall -d ${destroot}${applications_dir}/${app.name}.app/Contents/MacOS \
                         ${destroot}${applications_dir}/${app.name}.app/Contents/Resources
+        }
+    }
 
+    post-destroot {
+        if {[tbool app.create]} {
             # Ensure app.identifier is valid.
             if {[regexp -nocase {[^a-z0-9.-]} ${app.identifier}]} {
                 return -code error "app.identifier ${app.identifier} contains illegal characters"
@@ -218,8 +222,11 @@ platform macosx {
                 # If app.executable starts with ${workpath} or ${filespath}, copy it.
                 if {[string first ${workpath} ${executable}] == 0 || [string first ${filespath} ${executable}] == 0} {
                     xinstall ${executable} ${destroot}${applications_dir}/${app.name}.app/Contents/MacOS/${app.name}
+                
+                # app.executable refers to a file that exists but does not belong to this port.
+                # Assume it belongs to a dependency and symlink it.
                 } else {
-                    return -code error "app.executable ${app.executable} does not belong to this port"
+                    ln -s ${executable} ${destroot}${applications_dir}/${app.name}.app/Contents/MacOS/${app.name}
                 }
             } else {
                 return -code error "app.executable ${app.executable} does not exist"
