@@ -1,7 +1,7 @@
 # et:ts=4
 # select-1.0.tcl
 #
-# $Id: select-1.0.tcl 78606 2011-05-14 04:58:01Z jmr@macports.org $
+# $Id: select-1.0.tcl 100379 2012-12-10 09:29:24Z raimue@macports.org $
 #
 # Copyright (c) 2009 The MacPorts Project
 # Copyright (c) 2009 Rainer Mueller <raimue@macports.org>
@@ -19,7 +19,7 @@
 # 3. Neither the name of Apple Computer, Inc. nor the names of its
 #    contributors may be used to endorse or promote products derived from
 #    this software without specific prior written permission.
-# 
+#
 # THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 # "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 # LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -40,16 +40,21 @@ default select.file ""
 
 namespace eval select {}
 
-proc select::install {group file} {
+proc select::install {group file {name ""}} {
     global prefix destroot frameworks_dir applications_dir developer_dir
 
-    xinstall -m 755 -d ${destroot}${prefix}/etc/select/${group}
-    xinstall -m 644 ${file} ${destroot}${prefix}/etc/select/${group}
+    # Optional argument specifies file name
+    if {${name} == ""} {
+        set name [file tail ${file}]
+    }
 
-    reinplace s|\${prefix}|${prefix}|g ${destroot}${prefix}/etc/select/${group}/[file tail ${file}]
-    reinplace s|\${frameworks_dir}|${frameworks_dir}|g ${destroot}${prefix}/etc/select/${group}/[file tail ${file}]
-    reinplace s|\${applications_dir}|${applications_dir}|g ${destroot}${prefix}/etc/select/${group}/[file tail ${file}]
-    reinplace s|\${developer_dir}|${developer_dir}|g ${destroot}${prefix}/etc/select/${group}/[file tail ${file}]
+    xinstall -m 755 -d ${destroot}${prefix}/etc/select/${group}
+    xinstall -m 644 ${file} ${destroot}${prefix}/etc/select/${group}/${name}
+
+    reinplace s|\${prefix}|${prefix}|g ${destroot}${prefix}/etc/select/${group}/${name}
+    reinplace s|\${frameworks_dir}|${frameworks_dir}|g ${destroot}${prefix}/etc/select/${group}/${name}
+    reinplace s|\${applications_dir}|${applications_dir}|g ${destroot}${prefix}/etc/select/${group}/${name}
+    reinplace s|\${developer_dir}|${developer_dir}|g ${destroot}${prefix}/etc/select/${group}/${name}
 }
 
 post-destroot {
