@@ -1,5 +1,5 @@
---- src/sdk/configmanager.cpp.orig	2010-05-22 12:10:05.000000000 +0200
-+++ src/sdk/configmanager.cpp	2010-11-11 22:27:20.000000000 +0100
+--- src/sdk/configmanager.cpp.orig
++++ src/sdk/configmanager.cpp
 @@ -1442,8 +1442,10 @@ void ConfigManager::InitPaths()
  #ifdef CB_AUTOCONF
      if (plugin_path_global.IsEmpty())
