@@ -1,5 +1,5 @@
---- ../liw/lsm/lsm_check_entry.c	Tue Apr  9 00:28:35 1996
-+++ ../liw/lsm/lsm_check_entry.c.new	Mon Aug 30 18:26:12 2004
+--- liw/lsm/lsm_check_entry.c	Tue Apr  9 00:28:35 1996
++++ liw/lsm/lsm_check_entry.c.new	Mon Aug 30 18:26:12 2004
 @@ -6,8 +6,6 @@
   * "@(#)publib-lsm:$Id: lsm_check_entry.c,v 1.9 1996/04/08 22:28:35 liw Exp $"
   */
