@@ -1,8 +1,8 @@
 <?php
     /* -*- coding: utf-8; mode: php; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:set fenc=utf-8 filetype=php et sw=4 ts=4 sts=4: */
-    /* $Id: install.php 102557 2013-02-04 21:14:32Z jmr@macports.org $ */
+    /* $Id: install.php 114267 2013-12-04 06:20:17Z ryandesign@macports.org $ */
     /* Copyright (c) 2004, OpenDarwin. */
-    /* Copyright (c) 2004-2012, The MacPorts Project. */
+    /* Copyright (c) 2004-2013, The MacPorts Project. */
     include_once("includes/common.inc");
     print_header('The MacPorts Project -- Download &amp; Installation', 'utf-8');
 ?>
@@ -10,18 +10,34 @@
 
 <div id="content">
 
-    <h2 class="hdr">Installing MacPorts</h2>
+    <h2 class="hdr" id="quickstart">Quickstart</h2>
+
+    <ol>
+        <li>Install <a href="http://guide.macports.org/#installing.xcode">Xcode and the Xcode Command Line Tools</a></li>
+        <li>Agree to Xcode license in Terminal: <code>sudo xcodebuild -license</code></li>
+        <li>Install MacPorts for your version of OS X:
+            <ul>
+                <li><a href="<?php echo $mavericks_pkg; ?>"    >OS X 10.9 Mavericks</a></li>
+                <li><a href="<?php echo $mountainlion_pkg; ?>" >OS X 10.8 Mountain Lion</a></li>
+                <li><a href="<?php echo $lion_pkg; ?>"         >OS X 10.7 Lion</a></li>
+                <li><a href="#installing">Older OS? See here.</a></li>
+            </ul>
+        </li>
+    </ol>
+
+    <h2 class="hdr" id="installing">Installing MacPorts</h2>
 
     <p>MacPorts version <?php print $macports_version_latest; ?> is available in various formats for download and installation (note, if you are upgrading your Mac OS X to a new major release, see the <a href="https://trac.macports.org/wiki/Migration">migration info page</a>):
     </p>
 
     <ul>
-        <li>&#8220;pkg&#8221; installers for <a href="<?php print $mountainlion_pkg; ?>">Mountain Lion</a>,
-        <a href="<?php print $lion_pkg; ?>">Lion</a> and <a
-        href="<?php print $snowleopard_pkg; ?>">Snow Leopard</a>, for use with the Mac OS X Installer.
+        <li>&#8220;pkg&#8221; installers for <a href="<?php print $mavericks_pkg; ?>">Mavericks</a>,
+        <a href="<?php print $mountainlion_pkg; ?>">Mountain Lion</a> and
+        <a href="<?php print $lion_pkg; ?>">Lion</a>, for use with the Mac OS X Installer.
         This is the simplest installation
         procedure that most users should <a href="#pkg">follow</a> after meeting the requirements listed <a href="#requirements">
-        below</a>. Installers for legacy platforms <a href="<?php print $leopard_dmg; ?>">Leopard</a>
+        below</a>. Installers for legacy platforms <a
+        href="<?php print $snowleopard_pkg; ?>">Snow Leopard</a>, <a href="<?php print $leopard_dmg; ?>">Leopard</a>
         and <a href="<?php print $tiger_dmg; ?>">Tiger</a> are
         also available.</li>
         <li>In <a href="#source">source form</a> as either a <a href="<?php print $bz2_tarball ?>">tar.bz2</a> package or a
@@ -42,12 +58,13 @@
         components:</p>
 
         <ol>
-            <li>Apple's <a href="http://developer.apple.com/tools/xcode/">Xcode</a> Developer Tools (version 4.4 or later for Mountain Lion,
+            <li>Apple's <a href="https://developer.apple.com/technologies/tools/">Xcode</a> Developer Tools (version 5.0.1 or later
+            for Mavericks, 4.4 or later for Mountain Lion,
             4.1 or later for Lion, 3.2 or later for
-            Snow Leopard, or 3.1 or later for Leopard), found at the <a href="http://connect.apple.com/">Apple Developer Connection</a>
+            Snow Leopard, or 3.1 or later for Leopard), found at the <a href="https://developer.apple.com/downloads/">Apple Developer</a>
             site, on your Mac OS X installation CDs/DVD, or in the Mac App Store. Using the latest available version that will run on your
             OS is highly recommended.</li>
-            <li>Apple's Command Line Developer Tools are found at the <a href="http://connect.apple.com/">Apple Developer Connection</a> site,
+            <li>Apple's Command Line Developer Tools are found at the <a href="https://developer.apple.com/downloads/">Apple Developer</a> site,
             or they can be installed from within Xcode 4.  Users of Xcode 3 or earlier can install this by ensuring that the appropriate
             option(s) are selected at the time of Xcode's install ("UNIX Development", "System Tools", "Command Line Tools", or
             "Command Line Support").</li>
@@ -70,7 +87,8 @@
 
     <h3 class="subhdr" id="pkg">Mac OS X Package (.pkg) Installer</h3>
 
-    <p>The easiest way to install MacPorts on a Mac OS X system is by downloading the dmg for 
+    <p>The easiest way to install MacPorts on a Mac OS X system is by downloading the dmg for
+    <a href="<?php print $mavericks_pkg; ?>">Mavericks</a>,
     <a href="<?php print $mountainlion_pkg; ?>">Mountain Lion</a>,
     <a href="<?php print $lion_pkg; ?>">Lion</a>,
     <a href="<?php print $snowleopard_pkg; ?>">Snow Leopard</a>, <a href="<?php print $leopard_dmg;
@@ -206,7 +224,7 @@
     MacPorts. Of particular relevance are the <a href="<?php print $guide_url . '#installing'; ?>">installation</a> &amp;
     <a href="<?php print $guide_url . '#using'; ?>">usage</a> sections of the former and the <a href="<?php print $trac_url .
     'wiki/FAQ'; ?>">FAQ</a> section of the <a href="<?php print $trac_url . 'wiki'; ?>">Wiki</a>, where we keep track of questions
-    frequently fielded on our <a href="contact.php#lists">mailing lists</a>.</p>
+    frequently fielded on our <a href="contact.php#Lists">mailing lists</a>.</p>
 
     <p>If any of these resources do not answer your questions or if you need any kind of extended support, there are many ways
     to <a href="contact.php">contact us</a>!</p>
